print('哈喽，这是Tommy制作的Python第三方库')
import time
year = time.localtime()[0]
month = time.localtime()[1]
day = time.localtime()[2]
hour = time.localtime()[3]
minite = time.localtime()[4]
second = time.localtime()[5]
print('现在是{}年{}月{}日{}时{}分{}秒'.format(year,month,day,hour,minite,second))



import setuptools

with open('README.md','r',encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='tommytime04242',
    version='0.1.0',
    author='tommytju',
    author_email='1831412@tongji.edu.cn',
    description=long_description,
    long_desvription_content_type='text/markdown',
    url='https://space.bilibili.com/1900783',
    packages=setuptools.find_packages(),
    classfiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        ],
)
    
